@@ -1,13 +1,14 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level
-#of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 "Wharehouse"
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.backend import TableHandler
+from trytond.pyson import Not, Bool, Eval, Equal, PYSONEncoder, Date
 import datetime
 
 STATES = {
-    'readonly': "not active",
+    'readonly': Not(Bool(Eval('active'))),
 }
 
 
@@ -21,8 +22,8 @@ class Location(ModelSQL, ModelView):
     active = fields.Boolean('Active', select=1)
     address = fields.Many2One("party.address", "Address",
             states={
-                'invisible': "type != 'warehouse'",
-                'readonly': "not active",
+                'invisible': Not(Equal(Eval('type'), 'warehouse')),
+                'readonly': Not(Bool(Eval('active'))),
             })
     type = fields.Selection([
         ('supplier', 'Supplier'),
@@ -40,37 +41,40 @@ class Location(ModelSQL, ModelView):
     childs = fields.One2Many("stock.location", "parent", "Children")
     input_location = fields.Many2One(
         "stock.location", "Input", states={
-            'invisible': "type != 'warehouse'",
-            'readonly': "not active",
-            'required': "type == 'warehouse'",
+            'invisible': Not(Equal(Eval('type'), 'warehouse')),
+            'readonly': Not(Bool(Eval('active'))),
+            'required': Equal(Eval('type'), 'warehouse'),
         },
-        domain=["('type','=','storage')",
+        domain=[
+            ('type','=','storage'),
             ['OR',
-                "('parent', 'child_of', [active_id])",
-                "('parent', '=', False)"]])
+                ('parent', 'child_of', [Eval('active_id')]),
+                ('parent', '=', False),
+            ],
+        ])
     output_location = fields.Many2One(
         "stock.location", "Output", states={
-            'invisible': "type != 'warehouse'",
-            'readonly': "not active",
-            'required': "type == 'warehouse'",
+            'invisible': Not(Equal(Eval('type'), 'warehouse')),
+            'readonly': Not(Bool(Eval('active'))),
+            'required': Equal(Eval('type'), 'warehouse'),
         },
-        domain=["('type','=','storage')",
+        domain=[('type','=','storage'),
             ['OR',
-                "('parent', 'child_of', [active_id])",
-                "('parent', '=', False)"]])
+                ('parent', 'child_of', [Eval('active_id')]),
+                ('parent', '=', False)]])
     storage_location = fields.Many2One(
         "stock.location", "Storage", states={
-            'invisible': "type != 'warehouse'",
-            'readonly': "not active",
-            'required': "type == 'warehouse'",
+            'invisible': Not(Equal(Eval('type'), 'warehouse')),
+            'readonly': Not(Bool(Eval('active'))),
+            'required': Equal(Eval('type'), 'warehouse'),
         },
-        domain=["('type','=','storage')",
+        domain=[('type','=','storage'),
             ['OR',
-                "('parent', 'child_of', [active_id])",
-                "('parent', '=', False)"]])
-    quantity = fields.Function('get_quantity', type='float', string='Quantity')
-    forecast_quantity = fields.Function('get_quantity', type='float',
-                                        string='Forecast Quantity')
+                ('parent', 'child_of', [Eval('active_id')]),
+                ('parent', '=', False)]])
+    quantity = fields.Function(fields.Float('Quantity'), 'get_quantity')
+    forecast_quantity = fields.Function(fields.Float('Forecast Quantity'),
+            'get_quantity')
 
     def __init__(self):
         super(Location, self).__init__()
@@ -119,20 +123,14 @@ class Location(ModelSQL, ModelView):
     def check_xml_record(self, cursor, user, ids, values, context=None):
         return True
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            ids = self.search(cursor, user, [('code', '=', args[i][2])],
-                    context=context)
-            if ids:
-                args2.append(('id', 'in', ids))
-            else:
-                args2.append((self._rec_name, args[i][1], args[i][2]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        ids = self.search(cursor, user, [('code', '=', clause[2])],
+                order=[], context=context)
+        if ids:
+            return [('id', 'in', ids)]
+        return [(self._rec_name,) + clause[1:]]
 
-    def get_quantity(self, cursor, user, ids, name, arg, context=None):
+    def get_quantity(self, cursor, user, ids, name, context=None):
         product_obj = self.pool.get('product.product')
         date_obj = self.pool.get('ir.date')
 
@@ -316,16 +314,14 @@ Location()
 
 class Party(ModelSQL, ModelView):
     _name = 'party.party'
-    supplier_location = fields.Property(type='many2one',
-            relation='stock.location', string='Supplier Location',
-            domain=[('type', '=', 'supplier')],
-            help='The default source location ' \
-                    'when receiving products from the party.')
-    customer_location = fields.Property(type='many2one',
-            relation='stock.location', string='Customer Location',
-            domain=[('type', '=', 'customer')],
-            help='The default destination location ' \
-                    'when sending products to the party.')
+    supplier_location = fields.Property(fields.Many2One('stock.location',
+        'Supplier Location', domain=[('type', '=', 'supplier')],
+        help='The default source location when receiving products from the '
+        'party.'))
+    customer_location = fields.Property(fields.Many2One('stock.location',
+        'Customer Location', domain=[('type', '=', 'customer')],
+        help='The default destination location when sending products to the '
+        'party.'))
 
 Party()
 
@@ -372,23 +368,18 @@ class OpenProduct(Wizard):
     def _action_open_product(self, cursor, user, data, context=None):
         model_data_obj = self.pool.get('ir.model.data')
         act_window_obj = self.pool.get('ir.action.act_window')
-
-        model_data_ids = model_data_obj.search(cursor, user, [
-            ('fs_id', '=', 'act_product_by_location'),
-            ('module', '=', 'stock'),
-            ('inherit', '=', False),
-            ], limit=1, context=context)
-        model_data = model_data_obj.browse(cursor, user, model_data_ids[0],
-                context=context)
-        res = act_window_obj.read(cursor, user, model_data.db_id, context=context)
+        act_window_id = model_data_obj.get_id(cursor, user, 'stock',
+                'act_product_by_location', context=context)
+        res = act_window_obj.read(cursor, user, act_window_id, context=context)
 
         ctx = {}
         ctx['locations'] = data['ids']
         if data['form']['forecast_date']:
-            ctx['stock_date_end'] = data['form']['forecast_date']
+            date = data['form']['forecast_date']
         else:
-            ctx['stock_date_end'] = datetime.date.max
-        res['context'] = str(ctx)
+            date = datetime.date.max
+        ctx['stock_date_end'] = Date(date.year, date.month, date.day)
+        res['pyson_context'] = PYSONEncoder().encode(ctx)
 
         return res
 
